<?php
defined('BASEPATH') or exit('No direct script access allowed');
require_once APPPATH . '../vendor/autoload.php';

class Login extends CI_Controller
{

  public function __construct()
  {
    parent::__construct();
    $check = strstr(current_url(), 'signout') == '' && strstr(current_url(), '/theme') == '' && isset($_SESSION['xfront_customer']);
    if ($check && isset($_SESSION['xfront_back'])) {
      $back = $_SESSION['xfront_back'];
      unset($_SESSION['xfront_back']);
      redirect($back, 'refresh');
    } elseif ($check) {
      redirect(base_url('shop'), 'refresh');
    }
    $this->client = new Google_Client();
    $this->client->setClientId('1017187384186-40i12q26j8tkf0ms8r6gk3kmtmpa9ndi.apps.googleusercontent.com');
    $this->client->setClientSecret('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');
    $this->client->setRedirectUri(base_url('logged'));
    $this->client->addScope("email");
    $this->client->addScope("profile");

    $this->load->model('login_model');
  }

  public function index()
  {
    if ($this->input->get('k') === 'forgot_password')
      $this->forgot();
    else
      $this->load->view('index', ['data' => $this->index_model->_get_vars()]);
  }

  function login()
  {
    $this->load->view('login');
  }

  function register()
  {
    $this->load->view('register');
  }

  function signin($user = '', $pass = '')
  {
    if ($this->session->userdata('xfront_customer') != '')
      redirect(base_url(), 'refresh');

    $user = $this->input->post('miuser') ?: $user;
    $pass = $this->input->post('mipass') ?: $pass;
    if ($user == null && $pass == null) exit(json_encode(['status' => 'error', 'message' => 'Enter email and password']));
    if ($user == null) exit(json_encode(['status' => 'error', 'message' => 'Enter email']));
    if ($pass == null) exit(json_encode(['status' => 'error', 'message' => 'Enter password']));

    $login = $this->login_model->login($user, $pass);
    if (!$login) exit(json_encode(['status' => 'error', 'message' => 'No matching record for supplied login details']));
    if ($login->status != 0) exit(json_encode(['status' => 'error', 'message' => 'Access Denied!']));

    $cart = $_SESSION['xcel-cart'] ?? [];
    $cart = array_merge($cart, $this->login_model->_get_cart($login->token));
    if (count($cart) > 0) $_SESSION['xcel-cart'] = $cart;
    $_SESSION['xfront_name'] = $login->name;
    $_SESSION['xfront_user'] = $login->token;
    $_SESSION['xfront_customer'] = $login->token;
    echo json_encode(['status' => 'success', 'message' => 'Logged in. Redirecting...']);
  }

  function signup()
  {
    $name  = trim($this->input->post('miname'));
    $pass  = trim($this->input->post('mipass'));
    $pas2  = trim($this->input->post('mipass2'));
    $conf  = trim($this->input->post('miconfirm'));
    $phone = trim($this->input->post('miphone'));
    $email = trim($this->input->post('mimail'));

    $fone = str_replace(' ', '', $phone);
    $fone = str_replace('-', '', $phone);

    if ($name == '' or $pass == '' or $pas2 == '' or $fone == '' or $email == '') exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
    if (!is_numeric($fone) or strlen($fone) < 11 or $fone < 0)  exit(json_encode(['status' => 'error', 'message' => 'Phone number is invalid']));
    if (!filter_var($email, FILTER_VALIDATE_EMAIL))  exit(json_encode(['status' => 'error', 'message' => 'Enter a valid email address']));
    if ($this->login_model->check(['email' => $email])) exit(json_encode(['status' => 'error', 'message' => 'Email is registered to another user']));
    if ($pass != $pas2)  exit(json_encode(['status' => 'error', 'message' => 'Passwords do not match']));
    if (strlen($pass) < 8)  exit(json_encode(['status' => 'error', 'message' => 'Password must be at least 8 characters long']));
    if ($this->login_model->check(['phone' => $phone])) exit(json_encode(['status' => 'error', 'message' => 'Phone number is registered to another user']));
    if ($conf == '') exit(json_encode(['status' => 'error', 'message' => 'Check the box to confirm your agreement']));

    $data = [
      'name'      => $name,
      'phone'     => $phone,
      'email'     => $email,
      'type'      => 3,
      'password' => $pass,
    ];


    $reg = $this->login_model->_post($data);
    if (!$reg) exit(json_encode(['status' => 'failed', 'message' => 'A fatal error occurred during account creation']));
    $_SESSION['xfront_customer'] = $reg;
    $_SESSION['xfront_name'] = $name;
    unset($_SESSION['xfront_back']);
    exit(json_encode(['status' => 'success', 'message' => 'Registration Successful. Redirecting...']));
  }

  function google()
  {
    $loginURL = $this->client->createAuthUrl();
    redirect($loginURL);
  }

  function callback()
  {
    if (isset($_GET['code'])) {
      $token = $this->client->fetchAccessTokenWithAuthCode($_GET['code']);
      $this->client->setAccessToken($token);

      $google_oauth = new Google_Service_Oauth2($this->client);
      $user_data = $google_oauth->userinfo->get();

      $reg = $this->login_model->check(['email' => $user_data['email']]);
      $back = 'back';
      if (!$reg) {
        $data = [
          'name'      => $user_data['name'],
          'type'      => 2,
          'days'      => 0,
          'phone'     => '',
          'password'  => '',
          'email'     => $user_data['email'],
          'address'   => '',
          'warehouse' => ''
        ];
        $reg = $this->login_model->_post($data);
        $back = '';
      }
      $_SESSION['xfront_customer'] = $reg;
      unset($_SESSION['xfront_back']);
      $this->session->set_flashdata('xfront_message', "Welcome $back <b>" . $user_data['givenName'] . '</b>');
      redirect(base_url('shop.aspx'), 'refresh');
    }
  }

  function forgot()
  {
    if (isset($_SESSION['home'])) {
      unset($_SESSION['home']);
      redirect(base_url(), 'refresh');
    }
    if (!isset($_GET['action']))
      $this->load->view('password_reset');

    if ($this->input->get('action') == 'cancel') {
      $_SESSION['page'] = '';
    } elseif ($this->input->get('action') == 'email') {
      $mail = trim($this->input->post('mimail')) ?: $this->session->userdata('mail');
      if ($mail == '' or !filter_var($mail, FILTER_VALIDATE_EMAIL)) exit(json_encode(['status' => 'error', 'message' => 'Invalid Email Supplied']));
      $user = $this->login_model->get_email($mail);
      if (!$user) exit(json_encode(['status' => 'error', 'message' => 'Email does not match any records. <br>Please check for typing errors']));

      $settings = $this->login_model->settings();

      $code = strtoupper(substr(bin2hex(random_bytes(16)), 0, 6));

      $subject = "Password Reset";
      $message = $this->load->view('ionic_mail', ['user' => $user, 'code' => $code, 'settings' => $settings], true);
      $config['protocol']     = 'smtp';
      $config['smtp_host']    = 'ssl://xcelapp.test.gurugeeksroyalty.biz';
      $config['smtp_port']    = '465';
      $config['smtp_user']    = 'noreply@xcelapp.test.gurugeeksroyalty.biz';
      $config['smtp_pass']    = 'Xceltest12';
      $config['smtp_timeout'] = '7';
      $config['charset']      = 'iso-8859-1';
      $config['mailtype']     = 'html';
      $config['wordwrap']     = TRUE;
      $this->load->library('email', $config);
      $this->email->from('noreply@xcelapp.test.gurugeeksroyalty.biz', 'XCEL');
      $this->email->to($mail);
      $this->email->subject($subject);
      $this->email->message($message);

      $email = $this->email->send();
      if (!$email) exit(json_encode(['status' => 'error', 'message' => 'Failed to send password reset email']));

      $_SESSION['page'] = 'code';
      $_SESSION['code'] = $code;
      $_SESSION['user'] = $user->token;
      $_SESSION['uuid'] = $user->username;
      $_SESSION['mail'] = $mail;
      echo json_encode(['status' => 'success', 'message' => 'Email Sent!']);
    } elseif ($this->input->get('action') == 'code') {
      $code = $this->input->post('micode');

      if (!isset($_SESSION['code']) or $code != $_SESSION['code']) exit(json_encode(['status' => 'error', 'message' => 'Code is invalid']));

      $_SESSION['page'] = 'password';
      echo json_encode(['status' => 'success', 'message' => 'Verification Successful']);
    } elseif ($this->input->get('action') == 'password') {
      $p1 = $this->input->post('p1');
      $p2 = $this->input->post('p2');

      if ($p1 != $p2) exit(json_encode(['status' => 'error', 'message' => 'Passwords do not match']));

      $this->login_model->_put(['password' => password_hash("GG$p1", PASSWORD_DEFAULT)]);
      $_SESSION['home'] = true;
      unset($_SESSION['code']);
      unset($_SESSION['mail']);
      unset($_SESSION['page']);
      unset($_SESSION['user']);
      unset($_SESSION['uuid']);
      echo json_encode(['status' => 'success', 'message' => 'Password reset successful <br />Redirecting...']);
    }
  }

  function theme()
  {
    $color = $this->input->get('k');
    $this->load->helper('cookie');
    set_cookie('xcel_theme', $color, 21474836);
    echo 'Themed!';
  }

  function signout()
  {
    session_destroy();
    session_unset();
    unset($_SESSION);
    redirect(base_url());
  }
}
