<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Support_control extends CI_Controller
{

  public function __construct()
  {
    parent::__construct();
    if ($this->session->userdata('xfront_customer') == '') redirect(base_url(), 'refresh');

    $this->load->model('support_model');
  }

  public function index()
  {
    redirect('illegal_access');
  }

  function create()
  {
    $type     = trim($this->input->post('type'));
    $email    = trim($this->input->post('email'));
    $message  = trim($this->input->post('details'));

    if (!in_array($type, ['Dispatch', 'Payment']) or $email == '' or $message == '') exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
    if (!filter_var($email, FILTER_VALIDATE_EMAIL)) exit(json_encode(['status' => 'error', 'message' => 'Email is invalid']));

    $data = [
      'user' => $_SESSION['xfront_customer'],
      'type' => $type,
      'name'  => $_SESSION['xfront_name'],
      'remail' => $email,
      'message' => $message,
    ];

    if (!$this->support_model->_post($data))
      exit(json_encode(['status' => 'error', 'message' => 'A fatal error occurred <br />Sending failed']));

    // $this->session->set_flashdata('xfront_message', 'Your complaint has been registered');
    exit(json_encode(['status' => 'success', 'message' => 'Your complaint has been registered']));
  }

  function update()
  {
    if ($this->input->get('extras') == 'account') $this->account();

    $item     = trim($this->input->post('item'));
    $reason   = trim($this->input->post('reason'));
    $details  = trim($this->input->post('details'));
    $quantity = trim($this->input->post('quantity'));

    if (!in_array($reason, ['faulty', 'wrong', 'late']) or $item == '' or $quantity == '')
      exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
    $cart = $this->support_model->_get_cart($this->input->get('cart'), $item);
    if (!$cart) exit(json_encode(['status' => 'error', 'message' => 'A fatal error occurred. Please refresh and try again']));
    if (!is_numeric($quantity) or $quantity < 1) exit(json_encode(['status' => 'error', 'message' => 'Enter a valid quantity']));
    if ($quantity > $cart['quantity']) exit(json_encode(['status' => 'error', 'message' => 'You purchased only ' . number_format($cart['quantity']) . ' units of this product']));
    if ($this->support_model->_get_return($item, $cart['voucher'])) exit(json_encode(['status' => 'error', 'message' => 'You have already made a return request for this product']));

    $data = [
      'customer' => $_SESSION['xfront_customer'],
      'voucher'  => $cart['voucher'],
      'item'     => $item,
      'price'    => $cart['price'],
      'total'    => $cart['price'] * $quantity,
      'quantity' => $quantity
    ];
    $_SESSION['xcel-return'] = json_encode($data);
    exit(json_encode(['status' => 'success', 'message' => 'account']));
  }

  function account()
  {
    $name = trim($this->input->post('name'));
    $bank = trim($this->input->post('bank'));
    $numb = trim($this->input->post('number'));

    $cart = $this->support_model->_get_cart($this->input->get('cart'));
    if (!$cart) exit(json_encode(['status' => 'error', 'message' => 'A fatal error occurred. Please refresh and try again']));
    if ($name == '' or $bank == '' or $numb == '') exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
    if (!is_numeric($numb) or strlen($numb) < 10) exit(json_encode(['status' => 'error', 'message' => 'Enter a valid account number']));

    $ship = $this->support_model->_get_shipping($this->input->get('cart'));
    if (!$ship) exit(json_encode(['status' => 'error', 'message' => 'Cart data error!']));

    $data = json_decode($ship['shipping'], true);
    $data['account'] = ['name' => $name, 'bank' => $bank, 'number' => $numb];
    $this->support_model->_put_shipping($ship['token'], ['shipping' => json_encode($data)]);
    $this->support_model->_post_return(json_decode($_SESSION['xcel-return'], true));
    exit(json_encode(['status' => 'success', 'message' => 'succeeded']));
  }
}
