<?php
if (!defined('BASEPATH'))
  exit('No direct script access allowed');

class Payment_model extends CI_Model
{

  function __construct()
  {
    parent::__construct();
  }

  function _get_user()
  {
    if (!isset($_SESSION['xfront_customer'])) return [];
    $user = $this->db->get_where('er_customers', ['token' => $_SESSION['xfront_customer']]);
    if (!$user->num_rows() > 0) return [];
    return $user->row_array();
  }

  function _get_price($item, $state)
  {
    $items = $this->db->get_where('er_online_warehouse', ['token' => $item]);
    if (!($items->num_rows() > 0)) return 0;
    $price = json_decode($items->row('price'), true);
    $price = $price[$state][0] ?? 0;
    return $price;
  }

  function _get_total()
  {
    $this->db->where("`date` IS NULL");
    $sales = $this->db->get_where('er_sales', ['status' => 0, 'customer' => ($_SESSION['xfront_customer'] ?? '')]);
    if (!$sales->num_rows() > 0) return false;
    $total = 0;
    foreach ($sales->result_array() as $row) {
      $price = $this->_get_price($row['item'], 'a577f519b58b533e400cf28a7464576babf92121');
      $total += $price * $row['quantity'];
    }
    return $total;
  }

  function _get_shipping()
  {
    $shipping = $this->db->get_where('er_sales_extra', ['status' => 0, 'paid' => 0, 'customer' => $_SESSION['xfront_customer']]);
    if (!$shipping->num_rows() > 0) return false;
    return $shipping->row_array();
  }

  function _get_payment($ref = '')
  {
    if ($ref != '') $this->db->where('pid', $ref);
    $payment = $this->db->get_where('er_payments', ['status' => 0, 'paid' => 0, 'payer_id' => $_SESSION['xfront_customer']]);
    if (!$payment->num_rows() > 0) return false;
    return $payment->row_array();
  }

  function _get_status($customer, $voucher)
  {
    $this->db->select("SUM(amount) AS amount")->group_by('supply_id');
    $payments = $this->db->get_where('er_payments', ['payer_id' => $customer, 'supply_id' => $voucher, 'status' => 0]);
    if (!$payments->num_rows() > 0) return false;
    $this->db->select("SUM(total) AS total")->group_by('voucher');
    $sales = $this->db->get_where('er_sales', ['customer' => $customer, 'voucher' => $voucher]);
    if (!$sales->num_rows() > 0) return false;
    $pay = $payments->row('amount') - $sales->row('total');
    $shipping = $this->db->get_where('er_sales_extra', ['status' => 0, 'voucher' => $voucher]);
    if ($shipping->num_rows() > 0) $pay -= $shipping->row('shipping_fee');
    $response = ($pay >= 0) ? 'SETTLED in STYLE' : $pay;
    return $response;
  }

  function _put_payment($data, $chip)
  {
    $this->db->where('token', $chip);
    if (!$this->db->update('er_payments', $data)) return false;
    return true;
  }


  function _put_sale($chip)
  {
    $this->db->where(['voucher' => $chip, 'customer' => $_SESSION['xfront_customer'], 'status' => 0]);
    $this->db->set('date', 'NOW()', false);
    if (!$this->db->update('er_sales')) return false;
    return true;
  }

  function _pay_sale($data, $chip)
  {
    $this->db->where('voucher', $chip);
    $data['order_confirmed'] = 0;
    $data['order_status'] = 'Order Pending';
    if (!$this->db->update('er_sales', $data)) return false;
    return true;
  }

  function _post_notice($data, $customer)
  {
    $data['token'] = hash('sha256', time() . random_bytes(16));
    $data['done_by'] = $customer;
    if (!$this->db->insert('er_notification', $data)) return false;
    return true;
  }
}
