<?php
if (!defined('BASEPATH'))
  exit('No direct script access allowed');

class Receipt_model extends CI_Model
{

  function __construct()
  {
    parent::__construct();
  }

  function _get_outlets($status = '')
  {
    $this->db->order_by('type ASC, name ASC');
    $outlets = $this->db->get('er_warehouse');
    if (!($outlets->num_rows() > 0)) return false;
    return $outlets->result_array();
  }

  function _get($table, $token)
  {
    $table = 'er_' . $table;
    $data = $this->db->get_where($table, ['token' => $token, 'status' => 0]);
    if (!($data->num_rows() > 0)) return false;
    return $data->row();
  }

  function _get_items()
  {
    $this->db->order_by('name ASC');
    $items = $this->db->get('er_online_warehouse');
    if (!($items->num_rows() > 0)) return false;
    $items = $items->result_array();
    $item  = [];
    foreach ($items as $row) {
      $k = json_decode($row['price'], true) ?? [];
      $k = $k['a577f519b58b533e400cf28a7464576babf92121'] ?? 0;
      $item[$row['token']] = ['name' => $row['name'], 'price' => $k, 'status' => $row['status']];
    }
    return $item;
  }

  function _get_supply($token)
  {
    $table = 'er_supply';
    $supplies = $this->db->get_where('er_supply', ['token' => $token]);
    if (!($supplies->num_rows() > 0)) {
      $supplies = $this->db->get_where('er_sales', ['token' => $token]);
      $table = 'er_sales';
    }

    if (!($supplies->num_rows() > 0)) return false;

    $data = [];
    $supplies = $this->db->get_where($table, ['voucher' => $supplies->row('voucher')]);
    foreach ($supplies->result_array() as $row) {
      $out = array_key_exists('outlet', $row) ? $this->_get_outlet($row['outlet']) : $row['customer_name'];
      $stat = array_key_exists('outlet', $row) ? 1 : $row['paid'];
      $phone = array_key_exists('outlet', $row) ? $this->_get_settings()['phone'] : $row['customer_phone'];
      $data[] = [
        'date'     => strtotime($row['date']),
        'voucher'  => $row['voucher'],
        'receipt'  => $out,
        'phone'    => $phone,
        'item'     => $row['item'],
        'quantity' => $row['quantity'],
        'paid'     => $stat,
        'total'    => $row['total']
      ];
    }
    return $data;
  }

  function _get_sales($token)
  {
    $entry = $this->_get('sales', $token);
    if (!$entry) return false;
    $supplies = $this->db->get_where('er_sales', ['status' => 0, 'voucher' => $entry->voucher]);
    if (!($supplies->num_rows() > 0)) return false;
    return $supplies->result_array();
  }

  function _get_temps($waybill)
  {
    $data = [];
    $this->db->order_by('voucher');
    $sales = $this->db->get_where('er_sales', ['status' => 0, 'waybill' => $waybill]);
    if (($sales->num_rows() > 0)) {
      foreach ($sales->result_array() as $row) {
        $k = ['voucher' => $row['voucher'], 'status' => 0];
        $data[] = [
          'token'    => $row['token'],
          'date'     => strtotime($row['date']),
          'voucher'  => 'sale-' . $row['voucher'],
          'station'  => $row['customer_name'],
          'waybill'  => $row['waybill'],
          'item'     => $row['item'],
          'quantity' => $row['quantity'],
          'total'    => $row['total']
        ];
      }
    }
    $this->db->order_by('voucher');
    $sales = $this->db->get_where('er_supply', ['status' => 0, 'waybill' => $waybill]);
    if (($sales->num_rows() > 0)) {
      foreach ($sales->result_array() as $row) {
        $k = ['voucher' => $row['voucher'], 'status' => 0];
        $data[] = [
          'token'    => $row['token'],
          'date'     => strtotime($row['date']),
          'voucher'  => 'supp-' . $row['voucher'],
          'station'  => $this->_get_outlet($row['outlet']),
          'waybill'  => $row['waybill'],
          'item'     => $row['item'],
          'quantity' => $row['quantity'],
          'total'    => $row['total']
        ];
      }
    }
    if (count($data) == 0) return false;
    array_multisort(array_column($data, 'station'), SORT_ASC, $data);
    return $data;
  }

  function _get_waybill($token)
  {
    $entry = $this->db->get_where('er_waybill', ['token' => $token]);
    if ($entry->num_rows() < 1) return false;
    return $entry->row();
  }

  function _get_sums($table, $params)
  {
    $sum = 0;
    $table = 'er_' . $table;
    $this->db->select("SUM(total) as total");
    $this->db->group_by('voucher');
    $sql = $this->db->get_where($table, $params);
    if ($sql->num_rows() > 0) {
      $result = $sql->result_array();
      foreach ($result as $row) {
        $sum = $row['total'];
      }
    }
    return $sum;
  }

  function _get_outlet($token)
  {
    $outlet = $this->db->get_where('er_warehouse', ['token' => $token]);
    if (!($outlet->num_rows() > 0)) return false;
    return $outlet->row('name');
  }

  function _count($table, $filter = '')
  {
    $table = 'er_' . $table;
    if (is_array($filter)) $this->db->where($filter);
    return $this->db->count_all_results($table);
  }

  function _get_settings()
  {
    $data = $this->db->get_where('er_settings', ['status' => 0]);
    if (!($data->num_rows() > 0)) return false;
    $settings = [];
    foreach ($data->result_array() as $row) {
      $settings[$row['name']] = $row['value'];
    }
    return $settings;
  }
}
